@@ -35,7 +35,8 @@
 Univention Package Database
 Python module for the package database
 """
-from __future__ import annotations, print_function
+
+from __future__ import annotations
 
 import argparse
 import csv
@@ -146,7 +147,7 @@ def log(message):
     try:
         with open("/var/log/univention/pkgdb.log", "a") as logfile:  # TODO: persistent handle?
             logfile.write(time.strftime('%G-%m-%d %H:%M:%S') + ' ' + message + '\n')
-    except EnvironmentError:
+    except OSError:
         # no log, no real problem
         pass
 
